@@ -135,7 +135,7 @@ class Scheduler(object):
             logger.debug('Found new guy')
         return {row['id'] for row in cursor}
 
-    def create_events(self, team_id, schedule_id, user_id, events, role_id, cursor, skip_match=True, table_name='event'):
+    def create_events(self, team_id, schedule_id, user_id, events, role_id, cursor, table_name='event', skip_match=True):
         if len(events) == 0:
             return
         # Skip creating this epoch of events if matching events exist
@@ -406,5 +406,5 @@ class Scheduler(object):
             user_id = self.find_next_user_id(schedule, epoch, cursor, table_name)
             if not user_id:
                 continue
-            self.create_events(team_id, schedule['id'], user_id, epoch, role_id, cursor, table_name=table_name)
+            self.create_events(team_id, schedule['id'], user_id, epoch, role_id, cursor, table_name)
         connection.commit()
